@@ -9,7 +9,7 @@
 
 __all__ = ["MokeError", "task", "stdin", "stdout", "stderr", "num", "doc",
            "INFO", "WARN", "ERROR"]
-__version__ = "1.0.4"
+__version__ = "1.0.5"
 
 
 import os
@@ -97,12 +97,13 @@ class task(object):
     @staticmethod
     def _makelgr(args, cfg):
         # default arguments
+        options = ("level", "stream", "format")
         defargs = {"level":__deflog__["ll"],
                    "stream":__deflog__["ls"],
                    "format":__deflog__["lf"]
                    }
         # config file arguments
-        cfgargs = {}
+        cfgargs = dict.fromkeys(options)
         if cfg.has_section("log"):
             for name in ("level", "stream", "format"):
                 if cfg.has_option("log", name):
